@@ -15,7 +15,14 @@ QMainWindow(parent, Qt::FramelessWindowHint),
     ui->switchButton->setAttribute(Qt::WA_TranslucentBackground);
     palette.setColor(QPalette::Base, Qt::transparent);
     ui->centralWidget->setPalette(palette);
-    ui->switchButton->setPalette(palette);
+    ui->switchButton->setStyleSheet("background-color: grey; \
+     border-style: outset; \
+     border-width: 2px; \
+     border-radius: 10px; \
+     border-color: grey; \
+     font: bold 14px; \
+     min-width: 10em; \
+     padding: 6px;");
     QSettings settings;
     if (!settings.contains("profilechangerwidget/width"))
         settings.setValue("profilechangerwidget/width", 96);
