@@ -29,6 +29,8 @@ void SettingsDialog::accept()
         QMaemo5InformationBox::information(this, tr("Fields cannot be empty!"));
         return;
     }
+    QMaemo5InformationBox::information(this, "TranslationPath: " + QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+
     settings.setValue("profilechangerwidget/width", ui->widthBox->value());
     settings.setValue("profilechangerwidget/height", ui->heightBox->value());
     emit settingsChanged();
@@ -37,7 +39,6 @@ void SettingsDialog::accept()
 
 void SettingsDialog::showAbout()
 {
-    QMaemo5InformationBox::information(this, QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     QDialog *aboutDialog = new QDialog(0);
     aboutDialog->setAttribute(Qt::WA_DeleteOnClose);
     aboutDialog->setWindowTitle(tr("About Profile Changer Widget"));
